@@ -46,8 +46,6 @@ Event Name                               Description
 
 import wx
 
-import six
-
 from .control import RibbonControl
 from .art import *
 
@@ -345,7 +343,7 @@ class RibbonButtonBar(RibbonControl):
         if not bitmap.IsOk() and not bitmap_small.IsOk():
             raise Exception("Invalid main bitmap")
 
-        if not isinstance(help_string, six.string_types):
+        if not isinstance(help_string, str):
             raise Exception("Invalid help string parameter")
 
         if not self._buttons:
@@ -608,10 +606,10 @@ class RibbonButtonBar(RibbonControl):
         :see: :meth:`~RibbonButtonBar.ClearButtons`
         """
 
-        for button in self._buttons:
+        for i, button in enumerate(self._buttons):
             if button.id == button_id:
                 self._layouts_valid = False
-                self._buttons.pop(button)
+                self._buttons.pop(i)
                 self.Realize()
                 self.Refresh()
                 return True
@@ -1093,7 +1091,7 @@ class RibbonButtonBar(RibbonControl):
             # If height isn't preserved (i.e. it is reduced), then the minimum
             # size for the button bar will decrease, preventing the original
             # layout from being used (in some cases).
-            # It may be a good idea to always preverse the height, but for now
+            # It may be a good idea to always preserve the height, but for now
             # it is only done when the first button is involved in a collapse.
             preserve_height = True
 
