@@ -33,12 +33,9 @@
 
 import  locale
 import  wx
-import six
 
-if six.PY3:
-    # python 3 lacks cmp:
-    def cmp(a, b):
-        return (a > b) - (a < b)
+def cmp(a, b):
+    return (a > b) - (a < b)
 
 #----------------------------------------------------------------------------
 
@@ -47,7 +44,7 @@ class ColumnSorterMixin:
     A mixin class that handles sorting of a wx.ListCtrl in REPORT mode when
     the column header is clicked on.
 
-    There are a few requirments needed in order for this to work genericly:
+    There are a few requirements needed in order for this to work genericly:
 
       1. The combined class must have a GetListCtrl method that
          returns the wx.ListCtrl to be sorted, and the list control
@@ -106,7 +103,7 @@ class ColumnSorterMixin:
         Returns a tuple of image list indexesthe indexes in the image list for an image to be put on the column
         header when sorting in descending order.
         """
-        return (-1, -1)  # (decending, ascending) image IDs
+        return (-1, -1)  # (descending, ascending) image IDs
 
 
     def GetColumnSorter(self):
@@ -144,10 +141,12 @@ class ColumnSorterMixin:
         """
         Return a tuple containing the index of the column that was last sorted
         and the sort direction of that column.
-        Usage:
-        col, ascending = self.GetSortState()
-        # Make changes to list items... then resort
-        self.SortListItems(col, ascending)
+
+        Usage::
+
+            col, ascending = self.GetSortState()
+            # Make changes to list items... then resort
+            self.SortListItems(col, ascending)
         """
         return (self._col, self._colSortFlag[self._col])
 
@@ -159,10 +158,10 @@ class ColumnSorterMixin:
         item2 = self.itemDataMap[key2][col]
 
         #--- Internationalization of string sorting with locale module
-        if isinstance(item1, six.text_type) and isinstance(item2, six.text_type):
+        if isinstance(item1, str) and isinstance(item2, str):
             # both are unicode (py2) or str (py3)
             cmpVal = locale.strcoll(item1, item2)
-        elif isinstance(item1, six.binary_type) or isinstance(item2, six.binary_type):
+        elif isinstance(item1, bytes) or isinstance(item2, bytes):
             # at least one is a str (py2) or byte (py3)
             cmpVal = locale.strcoll(str(item1), str(item2))
         else:
@@ -459,7 +458,7 @@ class TextEditMixin:
 
     def make_editor(self, col_style=wx.LIST_FORMAT_LEFT):
 
-        style =wx.TE_PROCESS_ENTER|wx.TE_PROCESS_TAB|wx.TE_RICH2
+        style =wx.TE_PROCESS_ENTER|wx.TE_PROCESS_TAB
         style |= {wx.LIST_FORMAT_LEFT: wx.TE_LEFT,
                   wx.LIST_FORMAT_RIGHT: wx.TE_RIGHT,
                   wx.LIST_FORMAT_CENTRE : wx.TE_CENTRE
@@ -584,9 +583,9 @@ class TextEditMixin:
                 # don't start scrolling unless we really need to
                 offset = x0+x1-self.GetSize()[0]-scrolloffset
                 # scroll a bit more than what is minimum required
-                # so we don't have to scroll everytime the user presses TAB
+                # so we don't have to scroll every time the user presses TAB
                 # which is very tireing to the eye
-                addoffset = self.GetSize()[0]/4
+                addoffset = self.GetSize()[0]//4
                 # but be careful at the end of the list
                 if addoffset + scrolloffset < self.GetSize()[0]:
                     offset += addoffset
@@ -642,7 +641,7 @@ class TextEditMixin:
         ret = self.GetEventHandler().ProcessEvent(evt)
         if not ret or evt.IsAllowed():
             if self.IsVirtual():
-                # replace by whather you use to populate the virtual ListCtrl
+                # replace by whatever you use to populate the virtual ListCtrl
                 # data source
                 self.SetVirtualData(self.curRow, self.curCol, text)
             else:
